@@ -1,10 +1,8 @@
-import sys
-
-from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.functional import SimpleLazyObject
 from django.utils.importlib import import_module
 
+from celery_haystack.conf import settings
+
 
 def get_update_task(task_path=None):
     import_path = task_path or settings.CELERY_HAYSTACK_DEFAULT_TASK
